@@ -1,14 +1,31 @@
 package Dist::Zilla::Plugin::PodSyntaxTests;
 {
-  $Dist::Zilla::Plugin::PodSyntaxTests::VERSION = '4.300025';
+  $Dist::Zilla::Plugin::PodSyntaxTests::VERSION = '4.300026';
 }
 # ABSTRACT: a release test for Pod syntax
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::PrereqSource';
 
 use namespace::autoclean;
 
 
+
+# Register the release test prereq as a "develop requires"
+# so it will be listed in "dzil listdeps --author"
+sub register_prereqs {
+  my ($self) = @_;
+
+  $self->zilla->register_prereqs(
+    {
+      type  => 'requires',
+      phase => 'develop',
+    },
+    'Test::Pod' => '1.41',
+  );
+}
+
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -20,7 +37,7 @@ Dist::Zilla::Plugin::PodSyntaxTests - a release test for Pod syntax
 
 =head1 VERSION
 
-version 4.300025
+version 4.300026
 
 =head1 DESCRIPTION
 
@@ -29,6 +46,8 @@ following files:
 
   xt/release/pod-syntax.t   - a standard Test::Pod test
 
+L<Test::Pod> C<1.41> will be added as a C<develop requires> dependency.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
